@@ -17,7 +17,7 @@ def hypot(data):
 
     return result
 
-print hypot(a)
+print (hypot(a))
 
 # Notice inferred return type
 print hypot.signature
